# KappaModules

[![publish](https://github.com/BenediktAlkin/KappaModules/actions/workflows/publish.yaml/badge.svg)](https://github.com/BenediktAlkin/KappaModules/actions/workflows/publish.yaml)

# Setup

- new install: `pip install kappamodules`
- uprade to new version: `pip install kappamodules --upgrade` 
